﻿using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using RecrownedAthenaeum.SpecialTypes;
using RecrownedAthenaeum.UI.Skin.Definitions;

namespace RecrownedAthenaeum.UI.Modular.Modules.Interactive
{
    /// <summary>
    /// Button that holds a string.
    /// </summary>
    public class TextButton : Button
    {
        private Text text;

        /// <summary>
        /// The color the font should be rendered in.
        /// </summary>
        public Color FontColor { get { return text.color; } set { text.color = value; } }

        /// <summary>
        /// Constructs text button with the positions represented by <see cref="ISpecialDrawable"/>
        /// </summary>
        /// <param name="text">The string representing the text to be displayed.</param>
        /// <param name="font">The font to be used to display the text.</param>
        /// <param name="down">What to draw as button is pushed down.</param>
        /// <param name="up">What to draw as button is not pushed.</param>
        /// <param name="disabled">What to draw as button is disabled.</param>
        /// <param name="selected">What to draw as button is selected.</param>
        public TextButton(string text, SpriteFont font, ISpecialDrawable down, ISpecialDrawable up, ISpecialDrawable disabled = null, ISpecialDrawable selected = null) : base(down, up, disabled, selected)
        {
            this.text = new Text(font, text)
            {
                autoScale = true
            };
        }

        /// <summary>
        /// Constructs a text button using a skin and definition.
        /// </summary>
        /// <param name="text">The text to display.</param>
        /// <param name="skin">The skin to use.</param>
        /// <param name="definitionName">Name of the definition for this type in the skin given.</param>
        public TextButton(string text, Skin.Skin skin, string definitionName = null) : base(skin, definitionName)
        {
            TextButtonSkinDefinition skinDefinition = skin.ObtainDefinition<TextButtonSkinDefinition>(definitionName, GetType());
            this.text = new Text(skin.fonts[skinDefinition.fontName], text);
            FontColor = skin.colors[skinDefinition.fontColor];
        }

        /// <summary>
        /// Updates the text button.
        /// </summary>
        /// <param name="gameTime">Snapshot of information about time for game.</param>
        public override void Update(GameTime gameTime)
        {
            text.bounds = bounds;
            text.Update(gameTime);
            base.Update(gameTime);
        }

        /// <summary>
        /// Called whenever game wants to render this button.
        /// </summary>
        /// <param name="batch">Batch to use. Batch should already be started.</param>
        public override void Draw(SpriteBatch batch)
        {
            text.Draw(batch);
            base.Draw(batch);
        }
    }
}
